.. image:: https://zenodo.org/badge/122672643.svg
   :target: https://zenodo.org/badge/latestdoi/122672643
TTV2Fast2Furious
================

Welcome to TTV2Fast2Furious, a set of tools for analyzing transit timing variations.
See the code documentation at https://ttv2fast2furious.readthedocs.io

Install
-------

TTV2Fast2Furious is now on pip::

	pip install ttv2fast2furious

Acknowledgements
----------------
This project was developed in part at the Building Early Science with TESS meeting, which took place in 2019 March at the University of Chicago.
